==> am_mod_grp_0_1.tar.gz: am_mod_grp_0_1/components/grp/list.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

$menu_section = "group";

include_once ("config/grp.config.php");
include_once ("inc/grp_initiate.inc.php");

$body->set('group_config', $group_config);


if (isset($_POST['search'])) {
	if (isset($_POST['local']) && $_POST['local'] == 1) {
		$group->location_id = $_SESSION['location_id'];
	}
	
	if (!empty($_POST['search_text'])) {
		$group->search_text = $_POST['search_text'];
	}
}
elseif (isset($_REQUEST['view']) && $_REQUEST['view'] == "my_groups") {
	// get my participation
	$output_my_participation = $participation->selParticipants(null, null, $_SESSION['user_id']);
	
	if (!empty($output_my_participation)) {
		foreach ($output_my_participation as $key => $i):
			$group->group_ids[] = $i['item_id'];
		endforeach;
	}
}
else { // defaults to local new groups
	$group->status_id = $group_config['status']['live'];
}


require_once ("components/core/class/File.class.php");
$file = new File($db, $core_config['file']);
$file->module_id = $core_config['module_id']['group'];
$file->core_config_module = $core_config['module'];
$file->no_image = $core_config['file']['image']['thumb'][2]['no_image'];
$file->thumb = $core_config['file']['image']['thumb'][2]['suffix'];
$group->file = $file;


$output_groups = $group->selGroups();


if (!empty($output_groups)) {
	$body->set('groups', $output_groups);
}

?>

==> am_mod_grp_0_4.tar.gz: am_mod_grp_0_4/components/grp/list.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

$menu_section = "group";

include_once ("config/grp.config.php");
include_once ("inc/grp_initiate.inc.php");

$body->set('group_config', $group_config);


if (isset($_POST['search'])) {
	if (isset($_POST['local']) && $_POST['local'] == 1 && isset($_SESSION['location_id'])) {
		$group->location_id = $_SESSION['location_id'];
	}
	
	if (!empty($_POST['search_text'])) {
		$group->search_text = $_POST['search_text'];
	}
}
elseif (!empty($_REQUEST['tag'])) {
	$group->search_tag = $_REQUEST['tag'];
}
elseif (isset($_REQUEST['view']) && $_REQUEST['view'] == "my_groups" && isset($_SESSION['user_id'])) {
	// get my participation
	$output_my_participation = $participation->selParticipants(null, null, $_SESSION['user_id']);
	
	if (!empty($output_my_participation)) {
		foreach ($output_my_participation as $key => $i):
			$group->group_ids[] = $i['item_id'];
		endforeach;
	}
}
else { // defaults to local new groups
	$group->status_id = $group_config['status']['live'];
}


require_once ("components/core/class/File.class.php");
$file = new File($db, $core_config['file']);
$file->module_id = $core_config['module_id']['group'];
$file->core_config_module = $core_config['module'];
$file->no_image = $core_config['file']['image']['thumb'][2]['no_image'];
$file->thumb = $core_config['file']['image']['thumb'][2]['suffix'];
$group->file = $file;


$output_groups = $group->selGroups();


if (!empty($output_groups)) {
	$body->set('groups', $output_groups);
}
elseif (isset($_POST['search'])) {
	$lang['template_error']['err_no_items'] = str_replace('SYS_KEYWORD_SEARCH', $_POST['search_text'], $lang['txt_search_results_empty']);
}

?>
